# -*- coding: utf-8 -*-
# @Author  : llc
# @Time    : 2021/5/10 17:01
from pydantic import BaseModel

from flask_openapi3 import Info, OpenAPI, Tag

info = Info(title="book API", version="1.0.0")
app = OpenAPI(__name__, info=info)

book_tag = Tag(name="book", description="Some Book")


class BookQuery(BaseModel):
    age: int
    author: str


@app.get("/book", summary="get books", tags=[book_tag])
def get_book(query: BookQuery):
    """
    get all books
    """
    return {
        "code": 0,
        "message": "ok",
        "data": [
            {"bid": 1, "age": query.age, "author": query.author},
            {"bid": 2, "age": query.age, "author": query.author},
        ],
    }


if __name__ == "__main__":
    app.run(debug=True)
